@@ -31,9 +31,7 @@
 
 class KSslErrorUiData;
 
-namespace KManageSieve
-{
-
+namespace KManageSieve {
 class SieveJob;
 class SessionThread;
 
@@ -51,7 +49,7 @@ class Session : public QObject
     Q_OBJECT
 
 public:
-    explicit Session(QObject *parent = Q_NULLPTR);
+    explicit Session(QObject *parent = nullptr);
     ~Session();
 
     void connectToHost(const QUrl &url);
@@ -106,7 +104,6 @@ private:
 
     friend class SessionThread;
 };
-
 }
 
 #endif
