@@ -29,13 +29,22 @@ SelectMatchTypeComboBox::SelectMatchTypeComboBox(SieveEditorGraphicalModeWidget
 {
     mHasRegexCapability = sieveGraphicalModeWidget->sieveCapabilities().contains(QStringLiteral("regex"));
     initialize();
-    connect(this, static_cast<void (SelectMatchTypeComboBox::*)(int)>(&SelectMatchTypeComboBox::activated), this, &SelectMatchTypeComboBox::valueChanged);
+    connect(this, static_cast<void (SelectMatchTypeComboBox::*)(int)>(&SelectMatchTypeComboBox::activated), this, &SelectMatchTypeComboBox::slotValueChanged);
 }
 
 SelectMatchTypeComboBox::~SelectMatchTypeComboBox()
 {
 }
 
+void SelectMatchTypeComboBox::slotValueChanged(int val)
+{
+    if (mHasRegexCapability) {
+        const QString value = itemData(val).toString();
+        Q_EMIT switchToRegexp(value.contains(QStringLiteral("regex")));
+    }
+    Q_EMIT valueChanged();
+}
+
 void SelectMatchTypeComboBox::initialize()
 {
     addItem(i18n("is"), QStringLiteral(":is"));
@@ -65,9 +74,25 @@ void SelectMatchTypeComboBox::setCode(const QString &code, const QString &name,
     const int index = findData(code);
     if (index != -1) {
         setCurrentIndex(index);
+        if (mHasRegexCapability) {
+            //TODO optimize
+            const QString value = itemData(index).toString();
+            Q_EMIT switchToRegexp(value.contains(QStringLiteral("regex")));
+        }
     } else {
         AutoCreateScriptUtil::comboboxItemNotFound(code, name, error);
         setCurrentIndex(0);
     }
 }
 
+QStringList SelectMatchTypeComboBox::needRequires() const
+{
+    QStringList requires;
+    if (mHasRegexCapability) {
+        const QString value = itemData(currentIndex()).toString();
+        if (value.contains(QLatin1String("regex"))) {
+            requires << QStringLiteral("regex");
+        }
+    }
+    return requires;
+}
