@@ -23,16 +23,17 @@
 #include <KLocalizedString>
 
 #include <QWidget>
+#include <QXmlStreamWriter>
 
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 
 using namespace KSieveUi;
 
 SieveAction::SieveAction(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, const QString &name, const QString &label, QObject *parent)
-    : QObject(parent),
-      mSieveGraphicalModeWidget(sieveGraphicalModeWidget),
-      mName(name),
-      mLabel(label)
+    : QObject(parent)
+    , mSieveGraphicalModeWidget(sieveGraphicalModeWidget)
+    , mName(name)
+    , mLabel(label)
 {
 }
 
@@ -99,8 +100,9 @@ QString SieveAction::help() const
     return QString();
 }
 
-bool SieveAction::setParamWidgetValue(const QDomElement &, QWidget *, QString &)
+bool SieveAction::setParamWidgetValue(QXmlStreamReader &n, QWidget *, QString &)
 {
+    n.skipCurrentElement();
     return true;
 }
 
@@ -114,9 +116,9 @@ void SieveAction::setComment(const QString &comment)
     mComment = comment;
 }
 
-void SieveAction::unknownTag(const QString &tag, QString &error)
+void SieveAction::unknownTag(const QStringRef &tag, QString &error)
 {
-    error += i18n("An unknown tag \"%1\" was found during parsing action \"%2\".", tag, name()) + QLatin1Char('\n');
+    error += i18n("An unknown tag \"%1\" was found during parsing action \"%2\".", *tag.string(), name()) + QLatin1Char('\n');
 }
 
 void SieveAction::unknowTagValue(const QString &tagValue, QString &error)
@@ -124,9 +126,9 @@ void SieveAction::unknowTagValue(const QString &tagValue, QString &error)
     error += i18n("An unknown tag value \"%1\" was found during parsing action \"%2\".", tagValue, name()) + QLatin1Char('\n');
 }
 
-void SieveAction::tooManyArgument(const QString &tagName, int index, int maxValue, QString &error)
+void SieveAction::tooManyArgument(const QStringRef &tagName, int index, int maxValue, QString &error)
 {
-    error += i18n("Too many argument found for \"%1\", max value is %2, number of value found %3 for %4", name(), maxValue, index, tagName) + QLatin1Char('\n');
+    error += i18n("Too many argument found for \"%1\", max value is %2, number of value found %3 for %4", name(), maxValue, index, *tagName.string()) + QLatin1Char('\n');
 }
 
 void SieveAction::serverDoesNotSupportFeatures(const QString &feature, QString &error)
