@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,21 +19,19 @@
 #ifndef SIEVEACTIONKEEP_H
 #define SIEVEACTIONKEEP_H
 #include "sieveaction.h"
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveActionKeep : public SieveAction
 {
     Q_OBJECT
 public:
-    explicit SieveActionKeep(QObject *parent = Q_NULLPTR);
-    static SieveAction *newAction();
+    explicit SieveActionKeep(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
 
-    QString code(QWidget *) const Q_DECL_OVERRIDE;
-    QString help() const Q_DECL_OVERRIDE;
-    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
-    bool setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error) Q_DECL_OVERRIDE;
-    QStringList needRequires(QWidget *) const Q_DECL_OVERRIDE;
-    QUrl href() const Q_DECL_OVERRIDE;
+    QString code(QWidget *) const override;
+    QString help() const override;
+    QWidget *createParamWidget(QWidget *parent) const override;
+    bool setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error) override;
+    QStringList needRequires(QWidget *) const override;
+    QUrl href() const override;
 
 private:
     bool mHasFlagSupport;
