@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,13 +24,12 @@
 class KComboBox;
 class QLineEdit;
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SelectBodyTypeWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SelectBodyTypeWidget(QWidget *parent = Q_NULLPTR);
+    explicit SelectBodyTypeWidget(QWidget *parent = nullptr);
     ~SelectBodyTypeWidget();
 
     QString code() const;
