@@ -24,15 +24,14 @@
 
 class QPushButton;
 class QGridLayout;
-class QDomElement;
+class QXmlStreamReader;
+class QToolButton;
 
-namespace PimCommon
-{
+namespace PimCommon {
 class MinimumComboBox;
 }
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveCondition;
 class SieveHelpButton;
 class SieveEditorGraphicalModeWidget;
@@ -44,14 +43,16 @@ public:
     ~SieveConditionWidget();
 
     void updateAddRemoveButton(bool addButtonEnabled, bool removeButtonEnabled);
-    void generatedScript(QString &script, QStringList &requires);
-    void setCondition(const QString &conditionName, const QDomElement &element, bool notCondition, QString &error);
+    void generatedScript(QString &script, QStringList &requires, bool inForEveryPartLoop);
+    void setCondition(const QString &conditionName, QXmlStreamReader &element, bool notCondition, QString &error);
+    void clear();
 
 private Q_SLOTS:
     void slotAddWidget();
     void slotRemoveWidget();
     void slotConditionChanged(int index);
     void slotHelp();
+    void slotAddComment();
 
 Q_SIGNALS:
     void addWidget(QWidget *w);
@@ -61,13 +62,13 @@ Q_SIGNALS:
 private:
     void initWidget();
     void setFilterCondition(QWidget *widget);
-    void reset();
     QList<KSieveUi::SieveCondition *> mConditionList;
     QPushButton *mAdd;
     QPushButton *mRemove;
     PimCommon::MinimumComboBox *mComboBox;
     QGridLayout *mLayout;
     SieveHelpButton *mHelpButton;
+    QToolButton *mCommentButton;
     SieveEditorGraphicalModeWidget *mSieveGraphicalModeWidget;
 };
 
@@ -78,9 +79,9 @@ public:
     explicit SieveConditionWidgetLister(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QWidget *parent = nullptr);
     ~SieveConditionWidgetLister();
 
-    void generatedScript(QString &script, int &numberOfCondition, QStringList &requires);
+    void generatedScript(QString &script, int &numberOfCondition, QStringList &requires, bool inForEveryPartLoop);
     int conditionNumber() const;
-    void loadScript(const QDomElement &element, bool uniqTest, bool notCondition, QString &error);
+    void loadScript(QXmlStreamReader &element, bool uniqTest, bool notCondition, QString &error);
 
 Q_SIGNALS:
     void valueChanged();
@@ -90,11 +91,11 @@ public Q_SLOTS:
     void slotRemoveWidget(QWidget *w);
 
 protected:
-    void clearWidget(QWidget *aWidget) Q_DECL_OVERRIDE;
-    QWidget *createWidget(QWidget *parent) Q_DECL_OVERRIDE;
+    void clearWidget(QWidget *aWidget) override;
+    QWidget *createWidget(QWidget *parent) override;
 
 private:
-    void loadTest(const QDomElement &e, bool notCondition, QString &error);
+    void loadTest(QXmlStreamReader &e, bool notCondition, QString &error);
     void reconnectWidget(SieveConditionWidget *w);
     void updateAddRemoveButton();
     SieveEditorGraphicalModeWidget *mSieveGraphicalModeWidget;
