@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -27,8 +27,7 @@
 class QStackedWidget;
 class QLineEdit;
 class QAction;
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveImapAccountSettings;
 class SieveEditorTextModeWidget;
 class SieveEditorGraphicalModeWidget;
@@ -145,7 +144,6 @@ private:
     EditorMode mMode;
     bool mModified;
 };
-
 }
 
 #endif // SIEVEEDITORWIDGET_H
