@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,8 +20,7 @@
 
 #include <kpimtextedit/plaintextsyntaxspellcheckinghighlighter.h>
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveTextEdit;
 class SieveSyntaxSpellCheckingHighlighter : public KPIMTextEdit::PlainTextSyntaxSpellCheckingHighlighter
 {
@@ -31,7 +30,7 @@ public:
     ~SieveSyntaxSpellCheckingHighlighter();
 
 protected:
-    bool spellCheckBlock(const QString &text) Q_DECL_OVERRIDE;
+    bool spellCheckBlock(const QString &text) override;
 };
 }
 #endif // SIEVESYNTAXSPELLCHECKINGHIGHLIGHTER_H
