@@ -96,6 +96,7 @@ FindBarBase::FindBarBase(QWidget *parent)
 
     mStatus = new QLabel(this);
     mStatus->setObjectName(QStringLiteral("status"));
+    mStatus->setTextFormat(Qt::PlainText);
     QFontMetrics fm(mStatus->font());
     mNotFoundString = i18n("Phrase not found");
     mStatus->setFixedWidth(fm.width(mNotFoundString));
@@ -177,7 +178,6 @@ void FindBarBase::setFoundMatch(bool match)
     }
     mSearch->setStyleSheet(styleSheet);
 #endif
-
 }
 
 void FindBarBase::searchText(bool backward, bool isAutoSearch)
@@ -241,7 +241,7 @@ bool FindBarBase::event(QEvent *e)
     // Close the bar when pressing Escape.
     // Not using a QShortcut for this because it could conflict with
     // window-global actions (e.g. Emil Sedgh binds Esc to "close tab").
-    // With a shortcut Q_DECL_OVERRIDE we can catch this before it gets to kactions.
+    // With a shortcut override we can catch this before it gets to kactions.
     const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
     if (shortCutOverride || e->type() == QEvent::KeyPress) {
         QKeyEvent *kev = static_cast<QKeyEvent * >(e);
@@ -253,8 +253,8 @@ bool FindBarBase::event(QEvent *e)
             e->accept();
             closeBar();
             return true;
-        } else if (kev->key() == Qt::Key_Enter ||
-                   kev->key() == Qt::Key_Return) {
+        } else if (kev->key() == Qt::Key_Enter
+                   || kev->key() == Qt::Key_Return) {
             e->accept();
             if (shortCutOverride) {
                 return true;
@@ -272,4 +272,3 @@ bool FindBarBase::event(QEvent *e)
     }
     return QWidget::event(e);
 }
-
