@@ -22,15 +22,11 @@
 #include <QUrl>
 #include <QStringList>
 #include "ksieveui_private_export.h"
-class QDomDocument;
-class QDomElement;
-namespace KManageSieve
-{
+namespace KManageSieve {
 class SieveJob;
 }
-
-namespace KSieveUi
-{
+class QXmlStreamReader;
+namespace KSieveUi {
 class KSIEVEUI_TESTS_EXPORT ParseUserScriptJob : public QObject
 {
     Q_OBJECT
@@ -47,6 +43,7 @@ public:
     QStringList activeScriptList() const;
     QString error() const;
     void kill();
+    QStringList parsescript(const QString &script, bool &result);
 
 Q_SIGNALS:
     void finished(ParseUserScriptJob *job);
@@ -55,13 +52,13 @@ private:
     void slotGetResult(KManageSieve::SieveJob *job, bool, const QString &, bool);
     void emitSuccess(const QStringList &activeScriptList);
     void emitError(const QString &msgError);
-    static QString loadInclude(const QDomElement &element);
-    static QStringList extractActiveScript(const QDomDocument &doc);
-    static QStringList parsescript(const QString &script, bool &result);
+    QString loadInclude();
+    QStringList extractActiveScript(const QString &doc);
     QUrl mCurrentUrl;
     KManageSieve::SieveJob *mSieveJob;
     QStringList mActiveScripts;
     QString mError;
+    QXmlStreamReader *mStreamReader;
 };
 }
 
