@@ -24,8 +24,7 @@
 #include <QList>
 
 class QTextDocument;
-namespace KSieveUi
-{
+namespace KSieveUi {
 class XMLPrintingSyntaxHighLighter : public KPIMTextEdit::SyntaxHighlighterBase
 {
     Q_OBJECT
@@ -34,7 +33,7 @@ public:
     ~XMLPrintingSyntaxHighLighter();
 
 private:
-    void init() Q_DECL_OVERRIDE;
+    void init() override;
 };
 }
 #endif // XMLPRINTINGSYNTAXHIGHLIGHTER_H
