@@ -32,8 +32,8 @@
 
 using namespace KSieveUi;
 SieveTemplateListWidget::SieveTemplateListWidget(const QString &configName, QWidget *parent)
-    : PimCommon::TemplateListWidget(configName, parent),
-      mTemplateManager(nullptr)
+    : PimCommon::TemplateListWidget(configName, parent)
+    , mTemplateManager(nullptr)
 {
     setKNewStuffConfigFile(QStringLiteral("ksieve_script.knsrc"));
     loadTemplates();
