@@ -20,22 +20,20 @@
 
 class QString;
 
-namespace KManageSieve
-{
+namespace KManageSieve {
 class SieveJob;
 }
 
-namespace KSieveUi
-{
-
+namespace KSieveUi {
 class VacationDialog;
+class SieveImapPasswordProvider;
 
 class Vacation : public QObject
 {
     Q_OBJECT
 
 public:
-    explicit Vacation(QObject *parent = nullptr, bool checkonly = false, const QUrl &url = QUrl());
+    explicit Vacation(SieveImapPasswordProvider *passwordProvider, QObject *parent = nullptr, bool checkonly = false, const QUrl &url = QUrl());
     virtual ~Vacation();
 
     bool isUsable() const;
@@ -54,14 +52,14 @@ Q_SIGNALS:
     void requestEditVacation();
 
 protected Q_SLOTS:
-    void slotGetResult(KManageSieve::SieveJob *job, bool success,
-                       const QString &script, bool active);
+    void slotGetResult(KManageSieve::SieveJob *job, bool success, const QString &script, bool active);
     void slotDialogOk();
     void slotDialogCancel();
     void slotPutActiveResult(KManageSieve::SieveJob *, bool);
     void slotPutInactiveResult(KManageSieve::SieveJob *, bool);
 protected:
     // IO:
+    SieveImapPasswordProvider *mPasswordProvider;
     KManageSieve::SieveJob *mSieveJob;
     QUrl mUrl;
     QString mServerName;
@@ -70,7 +68,6 @@ protected:
     bool mWasActive;
     bool mCheckOnly;
 };
-
 }
 
 #endif
