@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -36,29 +36,25 @@ class KDateComboBox;
 
 class QDate;
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class PlainTextEditorWidget;
 }
 
 class QCheckBox;
 
-namespace KMime
-{
-namespace Types
-{
+namespace KMime {
+namespace Types {
 struct AddrSpec;
 typedef QVector<AddrSpec> AddrSpecList;
 }
 }
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class VacationEditWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit VacationEditWidget(QWidget *parent = Q_NULLPTR);
+    explicit VacationEditWidget(QWidget *parent = nullptr);
     ~VacationEditWidget();
 
     void enableDomainAndSendForSpam(bool enable = true);
