@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,17 +20,20 @@
 
 #include <widgets/managesievewidget.h>
 
-namespace KSieveUi
-{
+namespace KSieveUi {
+class SieveImapPasswordProvider;
 class CustomManageSieveWidget : public KSieveUi::ManageSieveWidget
 {
     Q_OBJECT
 public:
-    explicit CustomManageSieveWidget(QWidget *parent = nullptr);
+    explicit CustomManageSieveWidget(SieveImapPasswordProvider *passwordProvider, QWidget *parent = nullptr);
     virtual ~CustomManageSieveWidget();
 
 protected:
-    bool refreshList() Q_DECL_OVERRIDE;
+    bool refreshList() override;
+
+private:
+    SieveImapPasswordProvider *mPasswordProvider;
 };
 }
 
